# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/datalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2
from cogment.api import environment_pb2 as cogment_dot_api_dot_environment__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/datalog.proto',
  package='cogmentAPI',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x63ogment/api/datalog.proto\x12\ncogmentAPI\x1a\x18\x63ogment/api/common.proto\x1a\x1d\x63ogment/api/environment.proto\x1a\x19google/protobuf/any.proto\"{\n\x14RunTrialDatalogInput\x12/\n\x0ctrial_params\x18\x01 \x01(\x0b\x32\x17.cogmentAPI.TrialParamsH\x00\x12+\n\x06sample\x18\x02 \x01(\x0b\x32\x19.cogmentAPI.DatalogSampleH\x00\x42\x05\n\x03msg\"\x17\n\x15RunTrialDatalogOutput\"o\n\nSampleInfo\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12%\n\x05state\x18\x03 \x01(\x0e\x32\x16.cogmentAPI.TrialState\x12\x16\n\x0especial_events\x18\x04 \x03(\t\"\xd8\x01\n\rDatalogSample\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.cogmentAPI.SampleInfo\x12\x30\n\x0cobservations\x18\x02 \x01(\x0b\x32\x1a.cogmentAPI.ObservationSet\x12#\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x12.cogmentAPI.Action\x12#\n\x07rewards\x18\x04 \x03(\x0b\x32\x12.cogmentAPI.Reward\x12%\n\x08messages\x18\x05 \x03(\x0b\x32\x13.cogmentAPI.Message\"!\n\x0eTrialConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"!\n\x0e\x41\x63torConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\'\n\x14\x45nvironmentConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"r\n\x14\x45nvironmentParams_v1\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x30\n\x06\x63onfig\x18\x02 \x01(\x0b\x32 .cogmentAPI.EnvironmentConfig_v1\x12\x16\n\x0eimplementation\x18\x03 \x01(\t\"\x89\x01\n\x0e\x41\x63torParams_v1\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tor_class\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x16\n\x0eimplementation\x18\x04 \x01(\t\x12*\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x1a.cogmentAPI.ActorConfig_v1\"\xd0\x01\n\x0eTrialParams_v1\x12\x30\n\x0ctrial_config\x18\x01 \x01(\x0b\x32\x1a.cogmentAPI.TrialConfig_v1\x12\x35\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32 .cogmentAPI.EnvironmentParams_v1\x12*\n\x06\x61\x63tors\x18\x03 \x03(\x0b\x32\x1a.cogmentAPI.ActorParams_v1\x12\x11\n\tmax_steps\x18\x04 \x01(\r\x12\x16\n\x0emax_inactivity\x18\x05 \x01(\r\"7\n\x12ObservationData_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x10\n\x08snapshot\x18\x02 \x01(\x08\"\x81\x01\n\x11ObservationSet_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12\x34\n\x0cobservations\x18\x03 \x03(\x0b\x32\x1e.cogmentAPI.ObservationData_v1\x12\x12\n\nactors_map\x18\x04 \x03(\x05\"-\n\tAction_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x0f\n\x07tick_id\x18\x02 \x01(\x12\"r\n\x0fRewardSource_v1\x12\x13\n\x0bsender_name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\'\n\tuser_data\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"p\n\tReward_v1\x12\x15\n\rreceiver_name\x18\x01 \x01(\t\x12\x0f\n\x07tick_id\x18\x02 \x01(\x12\x12\r\n\x05value\x18\x03 \x01(\x02\x12,\n\x07sources\x18\x04 \x03(\x0b\x32\x1b.cogmentAPI.RewardSource_v1\"p\n\nMessage_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x13\n\x0bsender_name\x18\x02 \x01(\t\x12\x15\n\rreceiver_name\x18\x03 \x01(\t\x12%\n\x07payload\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\x80\x02\n\x10\x44\x61talogSample_v1\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x33\n\x0cobservations\x18\x02 \x01(\x0b\x32\x1d.cogmentAPI.ObservationSet_v1\x12&\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x15.cogmentAPI.Action_v1\x12&\n\x07rewards\x18\x04 \x03(\x0b\x32\x15.cogmentAPI.Reward_v1\x12(\n\x08messages\x18\x05 \x03(\x0b\x32\x16.cogmentAPI.Message_v1\x12,\n\ntrial_data\x18\x06 \x01(\x0b\x32\x18.cogmentAPI.TrialData_v1\"Y\n\x0cTrialData_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12%\n\x05state\x18\x03 \x01(\x0e\x32\x16.cogmentAPI.TrialState2\xab\x01\n\tDatalogSP\x12\\\n\x0fRunTrialDatalog\x12 .cogmentAPI.RunTrialDatalogInput\x1a!.cogmentAPI.RunTrialDatalogOutput\"\x00(\x01\x30\x01\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,cogment_dot_api_dot_environment__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_RUNTRIALDATALOGINPUT = _descriptor.Descriptor(
  name='RunTrialDatalogInput',
  full_name='cogmentAPI.RunTrialDatalogInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_params', full_name='cogmentAPI.RunTrialDatalogInput.trial_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample', full_name='cogmentAPI.RunTrialDatalogInput.sample', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='msg', full_name='cogmentAPI.RunTrialDatalogInput.msg',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=125,
  serialized_end=248,
)


_RUNTRIALDATALOGOUTPUT = _descriptor.Descriptor(
  name='RunTrialDatalogOutput',
  full_name='cogmentAPI.RunTrialDatalogOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=273,
)


_SAMPLEINFO = _descriptor.Descriptor(
  name='SampleInfo',
  full_name='cogmentAPI.SampleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.SampleInfo.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.SampleInfo.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.SampleInfo.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_events', full_name='cogmentAPI.SampleInfo.special_events', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=386,
)


_DATALOGSAMPLE = _descriptor.Descriptor(
  name='DatalogSample',
  full_name='cogmentAPI.DatalogSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='cogmentAPI.DatalogSample.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogmentAPI.DatalogSample.observations', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='cogmentAPI.DatalogSample.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='cogmentAPI.DatalogSample.rewards', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogmentAPI.DatalogSample.messages', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=605,
)


_TRIALCONFIG_V1 = _descriptor.Descriptor(
  name='TrialConfig_v1',
  full_name='cogmentAPI.TrialConfig_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.TrialConfig_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=640,
)


_ACTORCONFIG_V1 = _descriptor.Descriptor(
  name='ActorConfig_v1',
  full_name='cogmentAPI.ActorConfig_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.ActorConfig_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=642,
  serialized_end=675,
)


_ENVIRONMENTCONFIG_V1 = _descriptor.Descriptor(
  name='EnvironmentConfig_v1',
  full_name='cogmentAPI.EnvironmentConfig_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.EnvironmentConfig_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=716,
)


_ENVIRONMENTPARAMS_V1 = _descriptor.Descriptor(
  name='EnvironmentParams_v1',
  full_name='cogmentAPI.EnvironmentParams_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogmentAPI.EnvironmentParams_v1.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.EnvironmentParams_v1.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementation', full_name='cogmentAPI.EnvironmentParams_v1.implementation', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=832,
)


_ACTORPARAMS_V1 = _descriptor.Descriptor(
  name='ActorParams_v1',
  full_name='cogmentAPI.ActorParams_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cogmentAPI.ActorParams_v1.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_class', full_name='cogmentAPI.ActorParams_v1.actor_class', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogmentAPI.ActorParams_v1.endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementation', full_name='cogmentAPI.ActorParams_v1.implementation', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.ActorParams_v1.config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=972,
)


_TRIALPARAMS_V1 = _descriptor.Descriptor(
  name='TrialParams_v1',
  full_name='cogmentAPI.TrialParams_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_config', full_name='cogmentAPI.TrialParams_v1.trial_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='cogmentAPI.TrialParams_v1.environment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors', full_name='cogmentAPI.TrialParams_v1.actors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_steps', full_name='cogmentAPI.TrialParams_v1.max_steps', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_inactivity', full_name='cogmentAPI.TrialParams_v1.max_inactivity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1183,
)


_OBSERVATIONDATA_V1 = _descriptor.Descriptor(
  name='ObservationData_v1',
  full_name='cogmentAPI.ObservationData_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.ObservationData_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot', full_name='cogmentAPI.ObservationData_v1.snapshot', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1240,
)


_OBSERVATIONSET_V1 = _descriptor.Descriptor(
  name='ObservationSet_v1',
  full_name='cogmentAPI.ObservationSet_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.ObservationSet_v1.tick_id', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.ObservationSet_v1.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogmentAPI.ObservationSet_v1.observations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors_map', full_name='cogmentAPI.ObservationSet_v1.actors_map', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1372,
)


_ACTION_V1 = _descriptor.Descriptor(
  name='Action_v1',
  full_name='cogmentAPI.Action_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.Action_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Action_v1.tick_id', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1374,
  serialized_end=1419,
)


_REWARDSOURCE_V1 = _descriptor.Descriptor(
  name='RewardSource_v1',
  full_name='cogmentAPI.RewardSource_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='cogmentAPI.RewardSource_v1.sender_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogmentAPI.RewardSource_v1.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='cogmentAPI.RewardSource_v1.confidence', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='cogmentAPI.RewardSource_v1.user_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1421,
  serialized_end=1535,
)


_REWARD_V1 = _descriptor.Descriptor(
  name='Reward_v1',
  full_name='cogmentAPI.Reward_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver_name', full_name='cogmentAPI.Reward_v1.receiver_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Reward_v1.tick_id', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogmentAPI.Reward_v1.value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='cogmentAPI.Reward_v1.sources', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1537,
  serialized_end=1649,
)


_MESSAGE_V1 = _descriptor.Descriptor(
  name='Message_v1',
  full_name='cogmentAPI.Message_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Message_v1.tick_id', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='cogmentAPI.Message_v1.sender_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_name', full_name='cogmentAPI.Message_v1.receiver_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='cogmentAPI.Message_v1.payload', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1651,
  serialized_end=1763,
)


_DATALOGSAMPLE_V1 = _descriptor.Descriptor(
  name='DatalogSample_v1',
  full_name='cogmentAPI.DatalogSample_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='cogmentAPI.DatalogSample_v1.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogmentAPI.DatalogSample_v1.observations', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='cogmentAPI.DatalogSample_v1.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='cogmentAPI.DatalogSample_v1.rewards', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogmentAPI.DatalogSample_v1.messages', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_data', full_name='cogmentAPI.DatalogSample_v1.trial_data', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1766,
  serialized_end=2022,
)


_TRIALDATA_V1 = _descriptor.Descriptor(
  name='TrialData_v1',
  full_name='cogmentAPI.TrialData_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.TrialData_v1.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.TrialData_v1.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.TrialData_v1.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2024,
  serialized_end=2113,
)

_RUNTRIALDATALOGINPUT.fields_by_name['trial_params'].message_type = cogment_dot_api_dot_common__pb2._TRIALPARAMS
_RUNTRIALDATALOGINPUT.fields_by_name['sample'].message_type = _DATALOGSAMPLE
_RUNTRIALDATALOGINPUT.oneofs_by_name['msg'].fields.append(
  _RUNTRIALDATALOGINPUT.fields_by_name['trial_params'])
_RUNTRIALDATALOGINPUT.fields_by_name['trial_params'].containing_oneof = _RUNTRIALDATALOGINPUT.oneofs_by_name['msg']
_RUNTRIALDATALOGINPUT.oneofs_by_name['msg'].fields.append(
  _RUNTRIALDATALOGINPUT.fields_by_name['sample'])
_RUNTRIALDATALOGINPUT.fields_by_name['sample'].containing_oneof = _RUNTRIALDATALOGINPUT.oneofs_by_name['msg']
_SAMPLEINFO.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
_DATALOGSAMPLE.fields_by_name['info'].message_type = _SAMPLEINFO
_DATALOGSAMPLE.fields_by_name['observations'].message_type = cogment_dot_api_dot_environment__pb2._OBSERVATIONSET
_DATALOGSAMPLE.fields_by_name['actions'].message_type = cogment_dot_api_dot_common__pb2._ACTION
_DATALOGSAMPLE.fields_by_name['rewards'].message_type = cogment_dot_api_dot_common__pb2._REWARD
_DATALOGSAMPLE.fields_by_name['messages'].message_type = cogment_dot_api_dot_common__pb2._MESSAGE
_ENVIRONMENTPARAMS_V1.fields_by_name['config'].message_type = _ENVIRONMENTCONFIG_V1
_ACTORPARAMS_V1.fields_by_name['config'].message_type = _ACTORCONFIG_V1
_TRIALPARAMS_V1.fields_by_name['trial_config'].message_type = _TRIALCONFIG_V1
_TRIALPARAMS_V1.fields_by_name['environment'].message_type = _ENVIRONMENTPARAMS_V1
_TRIALPARAMS_V1.fields_by_name['actors'].message_type = _ACTORPARAMS_V1
_OBSERVATIONSET_V1.fields_by_name['observations'].message_type = _OBSERVATIONDATA_V1
_REWARDSOURCE_V1.fields_by_name['user_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_REWARD_V1.fields_by_name['sources'].message_type = _REWARDSOURCE_V1
_MESSAGE_V1.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_DATALOGSAMPLE_V1.fields_by_name['observations'].message_type = _OBSERVATIONSET_V1
_DATALOGSAMPLE_V1.fields_by_name['actions'].message_type = _ACTION_V1
_DATALOGSAMPLE_V1.fields_by_name['rewards'].message_type = _REWARD_V1
_DATALOGSAMPLE_V1.fields_by_name['messages'].message_type = _MESSAGE_V1
_DATALOGSAMPLE_V1.fields_by_name['trial_data'].message_type = _TRIALDATA_V1
_TRIALDATA_V1.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
DESCRIPTOR.message_types_by_name['RunTrialDatalogInput'] = _RUNTRIALDATALOGINPUT
DESCRIPTOR.message_types_by_name['RunTrialDatalogOutput'] = _RUNTRIALDATALOGOUTPUT
DESCRIPTOR.message_types_by_name['SampleInfo'] = _SAMPLEINFO
DESCRIPTOR.message_types_by_name['DatalogSample'] = _DATALOGSAMPLE
DESCRIPTOR.message_types_by_name['TrialConfig_v1'] = _TRIALCONFIG_V1
DESCRIPTOR.message_types_by_name['ActorConfig_v1'] = _ACTORCONFIG_V1
DESCRIPTOR.message_types_by_name['EnvironmentConfig_v1'] = _ENVIRONMENTCONFIG_V1
DESCRIPTOR.message_types_by_name['EnvironmentParams_v1'] = _ENVIRONMENTPARAMS_V1
DESCRIPTOR.message_types_by_name['ActorParams_v1'] = _ACTORPARAMS_V1
DESCRIPTOR.message_types_by_name['TrialParams_v1'] = _TRIALPARAMS_V1
DESCRIPTOR.message_types_by_name['ObservationData_v1'] = _OBSERVATIONDATA_V1
DESCRIPTOR.message_types_by_name['ObservationSet_v1'] = _OBSERVATIONSET_V1
DESCRIPTOR.message_types_by_name['Action_v1'] = _ACTION_V1
DESCRIPTOR.message_types_by_name['RewardSource_v1'] = _REWARDSOURCE_V1
DESCRIPTOR.message_types_by_name['Reward_v1'] = _REWARD_V1
DESCRIPTOR.message_types_by_name['Message_v1'] = _MESSAGE_V1
DESCRIPTOR.message_types_by_name['DatalogSample_v1'] = _DATALOGSAMPLE_V1
DESCRIPTOR.message_types_by_name['TrialData_v1'] = _TRIALDATA_V1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunTrialDatalogInput = _reflection.GeneratedProtocolMessageType('RunTrialDatalogInput', (_message.Message,), {
  'DESCRIPTOR' : _RUNTRIALDATALOGINPUT,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RunTrialDatalogInput)
  })
_sym_db.RegisterMessage(RunTrialDatalogInput)

RunTrialDatalogOutput = _reflection.GeneratedProtocolMessageType('RunTrialDatalogOutput', (_message.Message,), {
  'DESCRIPTOR' : _RUNTRIALDATALOGOUTPUT,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RunTrialDatalogOutput)
  })
_sym_db.RegisterMessage(RunTrialDatalogOutput)

SampleInfo = _reflection.GeneratedProtocolMessageType('SampleInfo', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLEINFO,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.SampleInfo)
  })
_sym_db.RegisterMessage(SampleInfo)

DatalogSample = _reflection.GeneratedProtocolMessageType('DatalogSample', (_message.Message,), {
  'DESCRIPTOR' : _DATALOGSAMPLE,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DatalogSample)
  })
_sym_db.RegisterMessage(DatalogSample)

TrialConfig_v1 = _reflection.GeneratedProtocolMessageType('TrialConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialConfig_v1)
  })
_sym_db.RegisterMessage(TrialConfig_v1)

ActorConfig_v1 = _reflection.GeneratedProtocolMessageType('ActorConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTORCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorConfig_v1)
  })
_sym_db.RegisterMessage(ActorConfig_v1)

EnvironmentConfig_v1 = _reflection.GeneratedProtocolMessageType('EnvironmentConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.EnvironmentConfig_v1)
  })
_sym_db.RegisterMessage(EnvironmentConfig_v1)

EnvironmentParams_v1 = _reflection.GeneratedProtocolMessageType('EnvironmentParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.EnvironmentParams_v1)
  })
_sym_db.RegisterMessage(EnvironmentParams_v1)

ActorParams_v1 = _reflection.GeneratedProtocolMessageType('ActorParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTORPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorParams_v1)
  })
_sym_db.RegisterMessage(ActorParams_v1)

TrialParams_v1 = _reflection.GeneratedProtocolMessageType('TrialParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialParams_v1)
  })
_sym_db.RegisterMessage(TrialParams_v1)

ObservationData_v1 = _reflection.GeneratedProtocolMessageType('ObservationData_v1', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONDATA_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ObservationData_v1)
  })
_sym_db.RegisterMessage(ObservationData_v1)

ObservationSet_v1 = _reflection.GeneratedProtocolMessageType('ObservationSet_v1', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONSET_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ObservationSet_v1)
  })
_sym_db.RegisterMessage(ObservationSet_v1)

Action_v1 = _reflection.GeneratedProtocolMessageType('Action_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTION_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Action_v1)
  })
_sym_db.RegisterMessage(Action_v1)

RewardSource_v1 = _reflection.GeneratedProtocolMessageType('RewardSource_v1', (_message.Message,), {
  'DESCRIPTOR' : _REWARDSOURCE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RewardSource_v1)
  })
_sym_db.RegisterMessage(RewardSource_v1)

Reward_v1 = _reflection.GeneratedProtocolMessageType('Reward_v1', (_message.Message,), {
  'DESCRIPTOR' : _REWARD_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Reward_v1)
  })
_sym_db.RegisterMessage(Reward_v1)

Message_v1 = _reflection.GeneratedProtocolMessageType('Message_v1', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Message_v1)
  })
_sym_db.RegisterMessage(Message_v1)

DatalogSample_v1 = _reflection.GeneratedProtocolMessageType('DatalogSample_v1', (_message.Message,), {
  'DESCRIPTOR' : _DATALOGSAMPLE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DatalogSample_v1)
  })
_sym_db.RegisterMessage(DatalogSample_v1)

TrialData_v1 = _reflection.GeneratedProtocolMessageType('TrialData_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALDATA_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialData_v1)
  })
_sym_db.RegisterMessage(TrialData_v1)



_DATALOGSP = _descriptor.ServiceDescriptor(
  name='DatalogSP',
  full_name='cogmentAPI.DatalogSP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2116,
  serialized_end=2287,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunTrialDatalog',
    full_name='cogmentAPI.DatalogSP.RunTrialDatalog',
    index=0,
    containing_service=None,
    input_type=_RUNTRIALDATALOGINPUT,
    output_type=_RUNTRIALDATALOGOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogmentAPI.DatalogSP.Version',
    index=1,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATALOGSP)

DESCRIPTOR.services_by_name['DatalogSP'] = _DATALOGSP

# @@protoc_insertion_point(module_scope)
